Persia
======

[![tutorials](https://img.shields.io/badge/tutorials-passing-green)](https://persiaml-tutorials.pages.dev) 
[![Documentation Status](https://img.shields.io/badge/documentation-passing-green)](https://persiaml.pages.dev)
 [![PyPI version](https://badge.fury.io/py/persia.svg)](https://badge.fury.io/py/persia) [![dockerhub](https://github.com/PersiaML/containers/actions/workflows/dockerhub.yml/badge.svg)](https://hub.docker.com/u/persiaml)
